import { ZoneEventTile } from '@prisma/client'
import prisma from '../utilities/prisma'
import { appLogger } from '../utilities/logger'

class ZoneEventTileRepository {

  async getAll(id: number): Promise<ZoneEventTile[]> {
    try {
      return await prisma.zoneEventTile.findMany({
        where: {
          zoneId: id
        }
      })
    } catch (error: any) {
      appLogger.error(`Failed to get zone event tiles: ${error.message}`)
      return []
    }
  }

  async getEventTileByZoneIdAndPosition(zoneId: number, positionX: number, positionY: number) {
    try {
      return await prisma.zoneEventTile.findFirst({
        where: {
          zoneId: zoneId,
          positionX: positionX,
          positionY: positionY
        },
        include: { teleport: true }
      })
    } catch (error: any) {
      appLogger.error(`Failed to get zone event tile: ${error.message}`)
      return null
    }
  }
}

export default new ZoneEventTileRepository()
